## Copyright (C) 2015 Michael Dippery <michael@monkey-robot.com>
## This work is free. You can redistribute it and/or modify it under the
## terms of the Do What The Fuck You Want To Public License, Version 2,
## as published by Sam Hocevar. See the COPYING file for more details.

"""anywho: WHOIS queries made easy"""

import socket


WHOIS_HOST = "whois.internic.net"
WHOIS_PORT = 43

MSG_LEN = 1024


def whois(domain):
    return _whois(domain)


def _whois(domain, whois_host=WHOIS_HOST, lookup_registrar=True):
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    sock.connect((whois_host, WHOIS_PORT))
    sock.send(domain + "\r\n")
    chunks = []
    while True:
        chunk = sock.recv(MSG_LEN)
        if not chunk:
            break
        chunks.append(chunk)
    data = "".join(chunks)
    if lookup_registrar:
        data += _follow_registrar(domain, data)
    return data


def _follow_registrar(domain, data):
    host = _registrar_whois(data)
    if not host:
        return ""
    return _whois(domain, host, lookup_registrar=False)


def _registrar_whois(data):
    for line in data.split("\n"):
        if line.strip().lower().find("whois server:") > -1:
            return line.strip().split(":", 1)[-1].strip()
    return None
